@@ -3,9 +3,8 @@ Name:    py416
 Author:  Ezio416
 Created: 2022-08-15
 Updated: 2022-08-18
-Version: 0.3
+Version: 0.4
 
 A collection of my custom-built functions
 '''
-from general import *
-
+from .general import *
\ No newline at end of file
